pub struct TrainingExample {
pub id: Uuid,
pub context_embeddings: Vec<Vec<f32>>,
pub message_embedding: Vec<f32>,
pub labels: IntentLabels,
pub metadata: ExampleMetadata,
}Expand description
A single training example for intent classification
Contains the input embeddings, soft labels from teacher, and metadata for traceability and debugging.
Fields
id: UuidUnique identifier for this example
context_embeddings: Vec<Vec<f32>>Context embeddings from the last N messages
Each inner Vec represents an embedding vector for one message. Order: oldest to newest (chronological).
message_embedding: Vec<f32>Embedding of the current message to classify
labels: IntentLabelsSoft labels from teacher model
metadata: ExampleMetadataMetadata about this example
Implementations
Sourceimpl TrainingExample
impl TrainingExample
Sourcepub fn new(
context_embeddings: Vec<Vec<f32>>,
message_embedding: Vec<f32>,
labels: IntentLabels,
) -> Self
pub fn new( context_embeddings: Vec<Vec<f32>>, message_embedding: Vec<f32>, labels: IntentLabels, ) -> Self
Create a new training example with minimal metadata
Sourcepub fn with_id(
id: Uuid,
context_embeddings: Vec<Vec<f32>>,
message_embedding: Vec<f32>,
labels: IntentLabels,
) -> Self
pub fn with_id( id: Uuid, context_embeddings: Vec<Vec<f32>>, message_embedding: Vec<f32>, labels: IntentLabels, ) -> Self
Create a new training example with specific ID
Sourcepub fn with_metadata(self, metadata: ExampleMetadata) -> Self
pub fn with_metadata(self, metadata: ExampleMetadata) -> Self
Set metadata for this example
Sourcepub fn embedding_dim(&self) -> usize
pub fn embedding_dim(&self) -> usize
Get the embedding dimension (from message embedding)
Sourcepub fn context_size(&self) -> usize
pub fn context_size(&self) -> usize
Get the context window size (number of context messages)
Sourcepub fn dominant_intent(&self) -> (&'static str, f32)
pub fn dominant_intent(&self) -> (&'static str, f32)
Get the dominant intent (highest probability label)